@@ -7,20 +7,20 @@ from dexguru_sdk.models.choices import TransactionChoices, ChainChoices, TokenTr
 
 
 class SwapBurnMintModel(BaseModel):
-    amm: AmmChoices
-    chain_id: ChainChoices
+    amm: str
+    chain_id: int
     direction: Optional[TokenTradeDirections]
     transaction_address: str
     timestamp: int
     block_number: int
-    to: str
-    sender: str
+    to: Optional[str] = None
+    sender: Optional[str] = None
     amount_usd: float
     tokens_in: List[dict]
     tokens_out: List[dict]
     pair_address: str
     wallet_address: str
-    wallet_category: constr(to_lower=True)
+    wallet_category: Optional[constr(to_lower=True)] = None
     transaction_type: TransactionChoices
 
     class SortFields(Enum):
