@@ -4,6 +4,7 @@ from pydantic import BaseModel, Field
 
 
 class TokenInventoryModel(BaseModel):
+    chain_id: int
     address: str
     name: str
     symbol: str
@@ -16,12 +17,14 @@ class TokensInventoryListModel(BaseModel):
 
 
 class TokenFinanceModel(BaseModel):
+    chain_id: int
     address: str
     volume_24h: float
     liquidity: float
     volume_24h_usd: float
     liquidity_usd: float
     price_usd: float
+    price_eth: float = None
     volume_24h_delta: float
     liquidity_24h_delta: float
     price_24h_delta: float
@@ -37,6 +40,7 @@ class TokensFinanceListModel(BaseModel):
 
 
 class TokenHistoryModel(BaseModel):
+    chain_id: int
     address: str
     volume_24h: float = Field(alias='volume24h_eth')
     liquidity: float
